@@ -1,5 +1,4 @@
 #!/bin/sh
-#
 
 BASH_BASE_SIZE=0x00000000
 CISCO_AC_TIMESTAMP=0x0000000000000000
@@ -8,6 +7,35 @@ CISCO_AC_OBJNAME=123456789012345678901234567890123456789012345678901234567890123
 # CISCO_AC_TIMESTAMP is also required for signing
 # comment is after BASH_BASE_SIZE or else sign tool will find the comment
 
+version() { echo "$@" | awk -F. '{ printf("%d%03d%05d\n", $1,$2,$3); }'; }
+
+checkInstalledVersion()
+{
+  failed=false
+  # version of DART being installed has to be greater than the current DART version
+  if [ -f ${DARTMANIFEST} ]; then
+      DARTPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${DARTMANIFEST})
+      DARTCURRVERSION=4.9.04043
+
+      if [ $(version $DARTCURRVERSION) -le $(version $DARTPREVVERSION) ]; then
+        failed=true
+      fi
+  fi
+
+  if [ "$failed" = true ]; then
+    if [ $(version $DARTCURRVERSION) -eq $(version $DARTPREVVERSION) ]; then
+      echo "Version ${DARTCURRVERSION} is already installed!"
+      echo "Version ${DARTCURRVERSION} is already installed!" >> /tmp/${LOGFNAME}
+    else
+      echo "A higher version ${DARTPREVVERSION} of DART is already installed!"
+      echo "A higher version ${DARTPREVVERSION} of DART is already installed!" >> /tmp/${LOGFNAME}
+    fi
+    echo "Exiting now."
+    echo "Exiting now." >> /tmp/${LOGFNAME}
+    exit 1
+  fi
+}
+
 LEGACY_DARTBIN="/opt/cisco/vpn/dart"
 LEGACY_UNINSTALL="${LEGACY_DARTBIN}/dart_uninstall.sh"
 
@@ -22,7 +50,9 @@ UNINSTALL="${VPNBIN}/dart_uninstall.sh"
 INSTALL=install
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.8.03052-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.9.04043-dart-webdeploy-k9-%Y%m%d%H%M%S.log"`
+
+DARTMANIFEST="${INSTPREFIX}/ACManifestDART.xml"
 
 # Make sure we are root
 if [ `id | sed -e 's/(.*//' ` != "uid=0" ]; then
@@ -69,7 +99,9 @@ if [ -f "license.txt" ]; then
                    ;;
       esac
     done
-fi 
+fi
+
+checkInstalledVersion
 
 if [ "`basename $0`" != "dart_install.sh" ]; then
 # dartsetup.sh is the binary that's been called
@@ -139,11 +171,6 @@ ${INSTALL} -d ${REQUESTDIR} || exit 1
 if [ -f "${NEWTEMP}/dart_uninstall.sh" ]; then
     echo "Installing "${NEWTEMP}/dart_uninstall.sh >> /tmp/${LOGFNAME}
     ${INSTALL} -o root -m 755 ${NEWTEMP}/dart_uninstall.sh ${VPNBIN} || exit 1
-
-    echo "Creating symlink "${VPNBIN}/dart_uninstall.sh >> /tmp/${LOGFNAME}
-    mkdir -p ${LEGACY_DARTBIN}
-    ln -f -s ${VPNBIN}/dart_uninstall.sh ${LEGACY_UNINSTALL} || exit 1
-    chmod 755 ${LEGACY_UNINSTALL}
 else
     echo "${NEWTEMP}/dart_uninstall.sh does not exist. It will not be installed."
 fi
