@@ -152,7 +152,7 @@ isAcKoCompatible()
     if [ "${ACKDFKOVERSION}" == "${KERNELRELEASE}" ]; then
         # AnyConnect Kernel module  is compatible with current kernel release.
         # return success.
-        return 0
+        return 2
     fi
  
     # anyconnect_kdf.ko is incompatible with current kernel version.
@@ -165,10 +165,14 @@ rebuildAcKdfKo()
 {
     # Check if anyconnect_kdf.ko is compatible with current kernel version. 
     isAcKoCompatible
-    if [ $? == 0 ]; then
-        # AnyConnect Kernel module is either not present or compatible with current kernel release.
-        RETVAL=2
-        return
+    ret=$?
+    if [ ${ret} == 0 ]; then
+        # AnyConnect Kernel module is not present
+        return 3
+    fi
+    if [ ${ret} == 2 ]; then
+        # AnyConnect Kernel module is compatible with current kernel release.
+        return 2
     fi
  
     # Remove existing anyconnect_kdf.ko and invoke kdf build script to create compatible anyconnect_kdf.ko .
@@ -180,11 +184,11 @@ rebuildAcKdfKo()
     if [ $? == 0 ]; then
         # AnyConnect kernel module is upgraded successfully.
         # return success
-        return
+        return 0
     fi
 
     # Failed to upgrade anyconnect_kdf.ko
-    RETVAL=1
+    return 1
 }
 
 # Makes anyconnect_kdf.ko module.
@@ -223,9 +227,10 @@ buildAcKdfKo()
         echo "Built AnyConnect kernel module successfully."
         cp -f ${ACKDFKO} ${DIRTOCOPYACKDFKO} || exit 1
         chmod 755 ${DIRTOCOPYACKDFKO}/${ACKDFKO}
+        return 0
     else
         echo "Failed to build AnyConnect Kernel module, exiting now."
-        RETVAL=1
+        return 1
     fi
 }
 
@@ -242,7 +247,8 @@ case "$1" in
     exit 1
 esac
 
+ret=$?
 # cleanup
 rm -rf ${TEMPDIR}
 
-exit ${RETVAL}
+exit ${ret}
