@@ -1,11 +1,12 @@
 #!/bin/sh
 
 ANYCONNECT_BINDIR="/opt/cisco/anyconnect/bin"
+NVM_BINDIR="/opt/cisco/anyconnect/NVM/bin"
 POSTURE_BINDIR="/opt/cisco/hostscan/bin"
 
 VPN_UNINST=${ANYCONNECT_BINDIR}/vpn_uninstall.sh
 POSTURE_UNINST=${POSTURE_BINDIR}/posture_uninstall.sh
-NVM_UNINST=${ANYCONNECT_BINDIR}/nvm_uninstall.sh
+NVM_UNINST=${NVM_BINDIR}/nvm_uninstall.sh
 
 if [ -x "${POSTURE_UNINST}" ]; then
   ${POSTURE_UNINST}
